@@ -1,6 +1,6 @@
 package XML::Struct::Reader;
 # ABSTRACT: Read XML streams into XML data structures
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 use strict;
 use Moo;
@@ -14,7 +14,7 @@ has path       => (is => 'rw', default => sub { '*' }, isa => \&_checkPath);
 has stream     => (is => 'rw'); # TODO: check with isa
 has from       => (is => 'rw', trigger => 1);
 has ns         => (is => 'rw', default => sub { '' });
-
+has depth      => (is => 'rw');
 has simple     => (is => 'rw', default => sub { 0 });
 has root       => (is => 'rw', default => sub { 0 });
 
@@ -90,7 +90,7 @@ sub readNext { # TODO: use XML::LibXML::Reader->nextPatternMatch for more perfor
         next if $stream->nodeType != XML_READER_TYPE_ELEMENT;
 
 #        printf " %d=%d %s:%s==%s\n", $stream->depth, scalar @parts, $stream->nodePath, $stream->name, join('/', @parts);
-        my $name = $self->ns eq 'strip' 
+        my $name = ($self->ns and $self->ns eq 'strip') 
             ? $stream->localName : $stream->name;
 
         if ($relative) {
@@ -108,8 +108,11 @@ sub readNext { # TODO: use XML::LibXML::Reader->nextPatternMatch for more perfor
 
     my $xml = $self->readElement($stream);
     return $self->simple 
-        ? XML::Struct::simpleXML( $xml, root => $self->root, attributes => $self->attributes ) 
-        : $xml;
+        ? XML::Struct::simpleXML( $xml, 
+            root => $self->root, 
+            attributes => $self->attributes,
+            depth => $self->depth 
+        ) : $xml;
 }
 
 *read = \&readNext;
@@ -197,7 +200,6 @@ sub readContent {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -206,7 +208,7 @@ XML::Struct::Reader - Read XML streams into XML data structures
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -299,6 +301,24 @@ Include ignorable whitespace as text elements (disabled by default)
 Set to 'C<strip>' to strip XML namespaces (including attributes). Expanding
 namespace URIs ('C<expand'>) is not supported yet.
 
+=item C<simple>
+
+Convert XML to simple key-value structure as known from L<XML::Simple>.
+
+=item C<root>
+
+When using option 'C<simple>' the root element is removed by default. Use this
+option to keep the root or to further set its element name.
+
+=item C<depth>
+
+When option 'C<simple>' is enabled, only transform to a given depth.  This
+option is useful for instance to access document-oriented XML embedded in data
+oriented XML. All elements below the given depth will be returned as ordered
+XML. Use any negative or non-numeric value for unlimited depth. The root
+element only counts as one level if option C<root> is enabled.  Depth zero (and
+depth one if with root) are only supported experimentally!
+
 =back
 
 =head1 AUTHOR
@@ -313,3 +333,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
